@@ -112,7 +112,8 @@ class NonlinearIOSystem(control.NonlinearIOSystem):
         if self.do_simulate_on_update:
             self.setTime(time)  # Consider time dependent functions
         # Adust the state
-        state_dct = {n: x_vec[i] for i, n in enumerate(self.state_names)}
+        state_dct = {n: np.max(x_vec[i], 0)
+              for i, n in enumerate(self.state_names)}
         self.ctlsb.set(state_dct)
         # Calculate the derivatives of floating species in state
         derivative_arr = np.array([v for v in self.ctlsb.get(self.dstate_names).values()])
@@ -125,6 +126,8 @@ class NonlinearIOSystem(control.NonlinearIOSystem):
     def _outfcn(self, time, x_vec, _, __):
         """
         Calculates the values of outputs.
+        Ensures that all state variables are non-negative since they are
+        rates or concentrations.
 
         Parameters
         ----------
@@ -143,6 +146,7 @@ class NonlinearIOSystem(control.NonlinearIOSystem):
         if np.isnan(np.sum(out_vec)):
             raise ValueError("Outputs could not be calculated.")
         #self.logger.add(time, self.ctlsb.get(self.state_names).values())
+        out_vec = np.array([np.max(v, 0) for v in out_vec])
         return out_vec
 
     def _makeStaircase(self, num_point, num_step, initial_value, final_value):
